<?php
/* $Id: slovak-windows-1250.inc.php,v 2.71 2005/03/30 19:24:23 lem9 Exp $ */

/* By: lubos klokner <erkac@vault-tec.sk> */

$charset = 'windows-1250';
$text_dir = 'ltr';
$left_font_family = '"verdana ce", "arial ce", verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'tahoma, "verdana ce", "arial ce", helvetica, arial, geneva, sans-serif';
$number_thousands_separator = ' ';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bajtov', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ne', 'Po', 't', 'St', 't', 'Pi', 'So');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mj', 'Jn', 'Jl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%B, %Y - %H:%M';
$timespanfmt = '%s dn, %s hodn, %s mint a %s seknd';

$strAPrimaryKey = 'Bol pridan primrny k pre %s';
$strAbortedClients = 'Preruen';
$strAbsolutePathToDocSqlDir = 'Prosm zadajte absoltnu cestu k adresru docSQL na serveri.';
$strAccessDenied = 'Prstup zamietnut';
$strAccessDeniedExplanation = 'phpMyAdmin sa poksil pripoji k MySQL serveru ale ten spojenie odmietol. Skontrolujte prosm meno serveru, pouvatesk meno a heslo v sbore config.inc.php a s tm, ktor ste dostali o administrtora MySQL servera.';
$strAction = 'Akcia';
$strAddAutoIncrement = 'Prida hodnotu AUTO_INCREMENT';
$strAddConstraints = 'Prida obmedzenia';
$strAddDeleteColumn = 'Prida/Odobra polia stpcov';
$strAddDeleteRow = 'Prida/Odobra kritria riadku';
$strAddDropDatabase = 'Prida DROP DATABASE';
$strAddHeaderComment = 'Prida vlastn komentr do hlaviky (\\n oddeuje riadky)';
$strAddIfNotExists = 'Prida IF NOT EXISTS';
$strAddIntoComments = 'Prida do komentrov';
$strAddNewField = 'Prida nov pole';
$strAddPrivilegesOnDb = 'Prida oprvnenia pre nasledujcu databzu';
$strAddPrivilegesOnTbl = 'Prida oprvnenia pre nasledujcu tabuku';
$strAddSearchConditions = 'Prida vyhadvacie parametre (obsah dotazu po "where" prkaze):';
$strAddToIndex = 'Prida do indexu &nbsp;%s&nbsp;stpec';
$strAddUser = 'Prida novho pouvatea';
$strAddUserMessage = 'Pouvate bol pridan.';
$strAddedColumnComment = 'Pridan komentr k stpcu';
$strAddedColumnRelation = 'Pridan vzah pre stpec';
$strAdministration = 'Administrcia';
$strAffectedRows = ' Ovplyvnen riadky: ';
$strAfter = 'Po %s';
$strAfterInsertBack = 'Sp';
$strAfterInsertNewInsert = 'Vloi nov zznam';
$strAfterInsertSame = 'Sp na tto strnku';
$strAll = 'Vetko';
$strAllTableSameWidth = 'zobrazi vetky tabuky s rovnakou rkou?';
$strAlterOrderBy = 'Zmeni poradie tabuky poda';
$strAnIndex = 'Bol pridan index pre %s';
$strAnalyzeTable = 'Analyzova tabuku';
$strAnd = 'a';
$strAny = 'Akkovek';
$strAnyHost = 'Akkovek hostite';
$strAnyUser = 'Akkovek pouvate';
$strArabic = 'Arabtina';
$strArmenian = 'Armntina';
$strAscending = 'Vzostupne';
$strAtBeginningOfTable = 'Na zaiatku tabuky';
$strAtEndOfTable = 'Na konci tabuky';
$strAttr = 'Atribty';
$strAutodetect = 'Automaticky zisti';
$strAutomaticLayout = 'Automatick rozvrhnutie';

$strBack = 'Sp';
$strBaltic = 'Baltick';
$strBeginCut = 'ZAIATOK VSEKU';
$strBeginRaw = 'ZAIATOK TOKU';
$strBinary = 'Binrny';
$strBinaryDoNotEdit = 'Binrny - neupravujte ';
$strBookmarkAllUsers = 'Dovoli pouva tto poloku vetkm pouvateom';
$strBookmarkDeleted = 'Zznam z obbench bol zmazan.';
$strBookmarkLabel = 'Nzov';
$strBookmarkOptions = 'Vlastnosti obbench';
$strBookmarkQuery = 'Obben SQL dotaz';
$strBookmarkThis = 'Prida tento SQL dotaz do obbench';
$strBookmarkView = 'Iba prezrie';
$strBrowse = 'Prechdza';
$strBrowseForeignValues = 'Prejs hodnoty cudzch kov';
$strBulgarian = 'Bulharsky';
$strBzError = 'nepodarilo sa skomprimova vstup z dvodu chybnho rozrenia pre kompresiu Bz2 v tejto verzii php. Doporuuje sa nastavi <code>$cfg[\'BZipDump\']</code> v konfigurcii phpMyAdmin na <code>FALSE</code>. Ak si elte pouva kompresiu Bz2 mali by ste naintalova noviu verziu php. Viac informci zskate z popisu chyby: %s.';
$strBzip = '"bzipped"';

$strCSVOptions = 'CSV nastavenia';
$strCalendar = 'Kalendr';
$strCannotLogin = 'Ned sa prihlsi k MySQL serveru';
$strCantLoad = 'ned sa nahra rozrenie %s,<br />prosm skontrolujte konfigurciu PHP';
$strCantLoadRecodeIconv = 'Nie je mon nahra rozrenie iconv alebo recode potrebn pre prevod znakovch sad. Upravte nastavenie php tak aby umoovalo poui tieto rozrenia alebo vypnite tto vlastnos v konfigurcii phpMyAdmina.';
$strCantRenameIdxToPrimary = 'Nie je mon premenova index na PRIMARY!';
$strCantUseRecodeIconv = 'Nie je mon poui funkcie iconv,libiconv a recode_string aj napriek tomu, e rozrenia s nahran. Skontrolujte prosm nastavenie PHP.';
$strCardinality = 'Mohutnos';
$strCarriage = 'Nvrat vozku (Carriage return): \\r';
$strCaseInsensitive = 'nerozliova vek a mal psmen';
$strCaseSensitive = 'rozliova vek a mal psmen';
$strCentralEuropean = 'Stredn Eurpa';
$strChange = 'Zmeni';
$strChangeCopyMode = 'Vytvori pouvatea s rovnakmi prvami a...';
$strChangeCopyModeCopy = '... zachova pvodnho pouvatea.';
$strChangeCopyModeDeleteAndReload = ' ... zmaza pvodnho pouvatea z tabuliek pouvateov a potom znovunata oprvnenia.';
$strChangeCopyModeJustDelete = ' ... zmaza pvodnho pouvatea z tabuliek pouvateov.';
$strChangeCopyModeRevoke = ' ... odobra vetky oprvnenia pvodnmu pouvateovi a nsledne ho zmaza.';
$strChangeCopyUser = 'Zmeni informcie o pouvateovi / Koprova pouvatea';
$strChangeDisplay = 'Zvolte, ktor pole zobrazi';
$strChangePassword = 'Zmeni heslo';
$strCharset = 'Znakov sada';
$strCharsetOfFile = 'Znakov sada sboru:';
$strCharsets = 'Znakov sady';
$strCharsetsAndCollations = 'Znakov sady a porovnvanie';
$strCheckAll = 'Oznai vetko';
$strCheckOverhead = 'Zvoli neoptimlne';
$strCheckPrivs = 'Skontrolova oprvnenia';
$strCheckPrivsLong = 'Skontrolova oprvnenia pre databzu &quot;%s&quot;.';
$strCheckTable = 'Skontrolova tabuku';
$strChoosePage = 'Prosm zvolte si Strnku, ktor chcete upravi';
$strColComFeat = 'Zobrazova komentre stpcov';
$strCollation = 'Porovnvanie';
$strColumnNames = 'Nzvy stpcov';
$strColumnPrivileges = 'Oprvnenia pre jednotliv stpce';
$strCommand = 'Prkaz';
$strComments = 'Komentre';
$strCommentsForTable = 'KOMENTRE PRE TABUKU';
$strCompleteInserts = 'pln vloenie';
$strCompression = 'Kompresia';
$strConfigFileError = 'phpMyAdmin was unable to read your configuration file!<br />This might happen if php finds a parse error in it or php cannot find the file.<br />Please call the configuration file directly using the link below and read the php error message(s) that you recieve. In most cases a quote or a semicolon is missing somewhere.<br />If you recieve a blank page, everything is fine.';
$strConfigureTableCoord = 'Prosm skonfigurujte koordinty pre tabuku %s';
$strConnectionError = 'Nepodarilo sa pripoji: chybn nastavenia.';
$strConnections = 'Spojenia';
$strConstraintsForDumped = 'Obmedzenie pre exportovan tabuky';
$strConstraintsForTable = 'Obmedzenie pre tabuku';
$strCookiesRequired = 'Cookies musia by povolen, pokia chcete pokraova.';
$strCopyTable = 'Skoprova tabuku do (databza<b>.</b>tabuka):';
$strCopyTableOK = 'Tabuka %s bola skorrovan do %s.';
$strCopyTableSameNames = 'Ned sa skoprova tabuka sama do seba!';
$strCouldNotKill = 'Neporadilo za zabi vlkno %s. Jeho beh bol pravdepodobne u ukonen.';
$strCreate = 'Vytvori';
$strCreateIndex = 'Vytvori index na&nbsp;%s&nbsp;stpcoch';
$strCreateIndexTopic = 'Vytvori nov index';
$strCreateNewDatabase = 'Vytvori nov databzu';
$strCreateNewTable = 'Vytvori nov tabuku v databze %s';
$strCreatePage = 'Vytvori nov Strnku';
$strCreatePdfFeat = 'Vytvranie PDF';
$strCreationDates = 'Dtum vytvorenia, poslednej zmeny a kontroly';
$strCriteria = 'Kritria';
$strCroatian = 'Chorvtsky';
$strCyrillic = 'Cyrilika';
$strCzech = 'esky';
$strCzechSlovak = 'etina/Slovenina';

$strDBComment = 'Komentr k databze: ';
$strDBGContext = 'Kontext';
$strDBGContextID = 'Kontext ID';
$strDBGHits = 'Zsahov';
$strDBGLine = 'Riadok';
$strDBGMaxTimeMs = 'Max. as, ms';
$strDBGMinTimeMs = 'Min as, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'as/Zsah, ms';
$strDBGTotalTimeMs = 'Celkov as, ms';
$strDBRename = 'Premenova databzu na';
$strDanish = 'Dnsky';
$strData = 'Dta';
$strDataDict = 'Dtov slovnk';
$strDataOnly = 'Iba dta';
$strDatabase = 'Databza';
$strDatabaseEmpty = 'Meno databzy je przdne!';
$strDatabaseExportOptions = 'Nastavenia exportu databz';
$strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
$strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
$strDatabases = 'databz(y)';
$strDatabasesDropped = 'spene zruench databz: %s.';
$strDatabasesStats = 'tatistiky databzy';
$strDatabasesStatsDisable = 'Skry tatistiky';
$strDatabasesStatsEnable = 'Zobrazi tatistiky';
$strDatabasesStatsHeavyTraffic = 'Poznmka: Aktivovanie tatistk databzy me spsobi znan zvenie sieovej prevdzky medzi databzou a web serverom.';
$strDbPrivileges = 'Oprvnenia pre jednotliv databzy';
$strDbSpecific = 'zvisl na databze';
$strDefault = 'Predvolen';
$strDefaultValueHelp = 'Pre predvolen hodnoty, prosm zadajte iba jednu hodnotu bez vodzoviek alebo uvdzacch znakov, napr.: a';
$strDefragment = 'Defragmentova tabuku';
$strDelOld = 'Aktulna strnka sa odkazuje na tabuky, ktor u neexistuj, elte si odstrni tieto odkazy?';
$strDelayedInserts = 'Poui oneskoren vloenia';
$strDelete = 'Zmaza';
$strDeleteAndFlush = 'Odstrni pouvateov a znovunata prva.';
$strDeleteAndFlushDescr = 'Toto je najistejie rieenie, ale znovunatanie prv me chvu trva.';
$strDeleted = 'Riadok bol zmazan';
$strDeletedRows = 'Zmazan riadky:';
$strDeleting = 'Odstrauje sa %s';
$strDescending = 'Zostupne';
$strDescription = 'Popis';
$strDictionary = 'slovnk';
$strDisableForeignChecks = 'Vypn kontrolu cudzch kov';
$strDisabled = 'Vypnut';
$strDisplayFeat = 'Zobrazi vlastnosti';
$strDisplayOrder = 'Zobrazi zoraden:';
$strDisplayPDF = 'Zobrazi schmu PDF';
$strDoAQuery = 'Vykona "dotaz poda prkladu" (nahradzujci znak: "%")';
$strDoYouReally = 'Skutone chcete vykona prkaz ';
$strDocu = 'Dokumentcia';
$strDrop = 'Odstrni';
$strDropDatabaseStrongWarning = 'Chystte sa ZRUI cel databzu!';
$strDropSelectedDatabases = 'Zrui vybran databzy';
$strDropUsersDb = 'Odstrni databzy s rovnakm menom ako maj pouvatelia.';
$strDumpSaved = 'Dump (schma) bol uloen do sboru %s.';
$strDumpXRows = 'Zobrazi %s riadkov od riadku %s.';
$strDumpingData = 'Sahujem dta pre tabuku';
$strDynamic = 'dynamick';

$strEdit = 'Upravi';
$strEditPDFPages = 'Upravi PDF Strnky';
$strEditPrivileges = 'Upravi oprvnenia';
$strEffective = 'Efektvny';
$strEmpty = 'Vyprzdni';
$strEmptyResultSet = 'MySQL vrtil przdny vsledok (tj. nulov poet riadkov).';
$strEnabled = 'Zapnut';
$strEncloseInTransaction = 'Uzatvori prkazy v transakcii';
$strEnd = 'Koniec';
$strEndCut = 'KONIEC VSEKU';
$strEndRaw = 'KONIEC TOKU';
$strEnglish = 'Anglicky';
$strEnglishPrivileges = ' Poznmka: nzvy MySQL oprvnen s uvdzan v anglitine. ';
$strError = 'Chyba';
$strEstonian = 'Estnsky';
$strExcelEdition = 'Verzia Excelu';
$strExcelOptions = 'Nastavenie exportu do Excelu';
$strExecuteBookmarked = 'Spusti obben dotaz';
$strExplain = 'Vysvetli SQL';
$strExport = 'Exportova';
$strExtendedInserts = 'Rozren vkladanie';
$strExtra = 'Extra';

$strFailedAttempts = 'Nepodarench pokusov';
$strField = 'Pole';
$strFieldHasBeenDropped = 'Pole %s bolo odstrnen';
$strFields = 'Polia';
$strFieldsEmpty = ' Poet pol je przdny! ';
$strFieldsEnclosedBy = 'Polia uzatvoren';
$strFieldsEscapedBy = 'Polia uveden pomocou';
$strFieldsTerminatedBy = 'Polia ukonen';
$strFileAlreadyExists = 'Sbor %s u existuje na servery, zmente nzov sboru alebo zvolte prepsanie sboru.';
$strFileCouldNotBeRead = 'Sbor sa ned preta';
$strFileNameTemplate = 'Vzor pre nzov sboru';
$strFileNameTemplateHelp = 'Pouite __DB__ ako nzov databzy, __TABLE__ ako nzov tabuky a akkovek parametre pre %sfunkciu strftime%s pre vloenie dt. Prpona sboru bude pridan automaticky poda typu. Akkovek in text zostane zachovan.';
$strFileNameTemplateRemember = 'zapamta si vzor';
$strFixed = 'pevn';
$strFlushPrivilegesNote = 'Poznmka: phpMyAdmin zskava prva pouvateov priamo z tabuliek MySQL. Obsah tchto tabuliek sa me li od prv, ktor pouva server, ak boli tieto tabuky rune upraven. V tomto prpade sa odpora vykona %sznovunatanie prv%s predtm ako budete pokraova.';
$strFlushTable = 'Vyprzdni tabuku ("FLUSH")';
$strFormEmpty = 'Chbajca poloka vo formulri !';
$strFormat = 'Formt';
$strFullText = 'Pln texty';
$strFunction = 'Funkcia';

$strGenBy = 'Vygenerovan';
$strGenTime = 'Vygenerovan:';
$strGeneralRelationFeat = 'Monosti veobecnch vzahov';
$strGeorgian = 'Gruznina';
$strGerman = 'Nemecky';
$strGlobal = 'globlny';
$strGlobalPrivileges = 'Globlne prva';
$strGlobalValue = 'Globlna hodnota';
$strGo = 'Vykonaj';
$strGrantOption = 'Prideli';
$strGreek = 'Grtina';
$strGzip = '"gzip-ovan"';

$strHasBeenAltered = 'bola zmenen.';
$strHasBeenCreated = 'bola vytvoren.';
$strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
$strHebrew = 'Hebrejsky';
$strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
$strHome = 'Domov';
$strHomepageOfficial = 'Oficilne strnky phpMyAdmin-a';
$strHost = 'Hostite';
$strHostEmpty = 'Nzov hostitea je przdny!';
$strHungarian = 'Maarsky';

$strIcelandic = 'Islandina';
$strId = 'ID';
$strIdxFulltext = 'Cel text';
$strIfYouWish = 'Ak si elte nahra iba urit stpce tabuky, pecifikujte ich ako zoznam pol oddelen iarkou.';
$strIgnore = 'Ignorova';
$strIgnoreInserts = 'Poui IGNORE';
$strIgnoringFile = 'Ignorujem sbor %s';
$strImportDocSQL = 'Importova sbory docSQL';
$strImportFiles = 'Importova sbory';
$strImportFinished = 'Importovanie ukonen';
$strInUse = 'prve sa pouva';
$strIndex = 'Index';
$strIndexHasBeenDropped = 'Index pre %s bol odstrnen';
$strIndexName = 'Meno indexu&nbsp;:';
$strIndexType = 'Typ indexu&nbsp;:';
$strIndexes = 'Indexy';
$strInnodbStat = 'Stav InnoDB';
$strInsecureMySQL = 'Konfiguran sbor obsahuje nastavenia (root bez hesla), ktor zodpovedaj predvolenmu privilegovanmu MySQL tu. Ak MySQL server be s tmto nastavenm, nie je zabezpeen proti napadnutiu, tto bezpenostn chyba by mala by urchlene odstrnen.';
$strInsert = 'Vloi';
$strInsertAsNewRow = 'Vloi ako nov riadok';
$strInsertNewRow = 'Vloi nov riadok';
$strInsertTextfiles = 'Vloi textov sbory do tabuky';
$strInsertedRowId = 'Id vloenho riadku:';
$strInsertedRows = 'Vloen riadky:';
$strInstructions = 'Intrukcie';
$strInternalNotNecessary = '* Vntorn vzah nie je nutn ak u vzah existuje v InnoDB.';
$strInternalRelations = 'Intern vzahy';

$strJapanese = 'Japonina';
$strJumpToDB = 'Na databzu &quot;%s&quot;.';
$strJustDelete = 'Iba odstrni pouvatelov z tabuliek prv.';
$strJustDeleteDescr = '&quot;Odstrnen&quot; pouvatelia bud ma k serveru ako predtm a do znovunatania prv.';

$strKeepPass = 'Nezmeni heslo';
$strKeyname = 'Kov nzov';
$strKill = 'Zabi';
$strKorean = 'Krejina';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Nastavenia LaTeX';
$strLandscape = 'Na rku';
$strLatexCaption = 'Nadpis tabuky';
$strLatexContent = 'Obsah tabuky __TABLE__';
$strLatexContinued = '(pokraovanie)';
$strLatexContinuedCaption = 'Nadpis pokraovania tabuky';
$strLatexIncludeCaption = 'Zahrn nadpis tabuky';
$strLatexLabel = 'Nvestie';
$strLatexStructure = 'truktra tabuky __TABLE__';
$strLatvian = 'Lotystina';
$strLengthSet = 'Dka/Nastavi*';
$strLimitNumRows = 'zznamov na strnku';
$strLineFeed = 'Ukonenie riadku (Linefeed): \\n';
$strLinesTerminatedBy = 'Riadky ukonen';
$strLinkNotFound = 'Linka nebola njden';
$strLinksTo = 'Linkova na';
$strLithuanian = 'Litovsky';
$strLoadExplanation = 'Automaticky s nastaven najlepie hodnoty, ak toto nastavenie nebude fungova, mete sksi druh monos.';
$strLoadMethod = 'Parametre pre prkaz LOAD';
$strLocalhost = 'Loklny';
$strLocationTextfile = 'Lokcia textovho sboru';
$strLogPassword = 'Heslo:';
$strLogServer = 'Server';
$strLogUsername = 'Pouvate:';
$strLogin = 'Login';
$strLoginInformation = 'Prihlsenie';
$strLogout = 'Odhlsi sa';

$strMIMETypesForTable = 'MIME TYPY PRE TABUKU';
$strMIME_MIMEtype = 'MIME typ';
$strMIME_available_mime = 'Dostupn MIME typy';
$strMIME_available_transform = 'Dostupn transformcie';
$strMIME_description = 'Popis';
$strMIME_nodescription = 'Nie je dostupn iadny popis pre tto transformciu.<br />Kontaktujte autora, ktor %s vytra.';
$strMIME_transformation = 'Transformcia pri prehliadan';
$strMIME_transformation_note = 'Pre zoznam dostupnch parametrov a ich MIME typov kliknite na %spopisy transformci';
$strMIME_transformation_options = 'Parametre transformcie';
$strMIME_transformation_options_note = 'Prosm zadajte hodnoty pre parametre transformcie v nasledujcom tvare: \'a\',\'b\',\'c\'...<br />Ak potrebujete poui sptn lomtko ("\") alebo jednoduch vodzovky ("\'") medzi tmito hodnotami, vlote pred nich sptn lomtko (napr. \'\\\\xyz\' alebo \'a\\\'b\').';
$strMIME_without = 'MIME typy zobrazen kurzvou nemaj vlastn transforman funkciu';
$strMaximumSize = 'Maximlna vekos: %s%s';
$strModifications = 'Zmeny boli uloen';
$strModify = 'Zmeni';
$strModifyIndexTopic = 'Modifikova index';
$strMoreStatusVars = 'alie informcie o stave';
$strMoveTable = 'Presun tabuku do (databza<b>.</b>tabuka):';
$strMoveTableOK = 'Tabuka %s bola presunut do %s.';
$strMoveTableSameNames = 'Ned sa presun tabuka sama do seba!';
$strMultilingual = 'mnohojazyn';
$strMustSelectFile = 'Zvolte prosm sbor, ktor si elte vloi.';
$strMySQLCharset = 'Znakov sada v MySQL';
$strMySQLConnectionCollation = 'Overenie MySQL spojenia';
$strMySQLReloaded = 'MySQL znovu-natan.';
$strMySQLSaid = 'MySQL hlsi: ';
$strMySQLServerProcess = 'MySQL %pma_s1% be na %pma_s2% ako %pma_s3%';
$strMySQLShowProcess = 'Zobrazi procesy';
$strMySQLShowStatus = 'Zobrazi MySQL informcie o behu';
$strMySQLShowVars = 'Zobrazi MySQL systmov premenn';

$strName = 'Nzov';
$strNeedPrimaryKey = 'Pre tto tabuku by ste mali definova primrny k.';
$strNext = 'al';
$strNo = 'Nie';
$strNoDatabases = 'iadne databzy';
$strNoDatabasesSelected = 'Neboli vybran iadne databzy.';
$strNoDescription = 'bez Popisu';
$strNoDropDatabases = 'Monos "DROP DATABASE" vypnut.';
$strNoExplain = 'Preskoi vysvetlenie SQL';
$strNoFrames = 'phpMyAdmin funguje lepie s prehliadami podporujcimi <b>rmy</b>.';
$strNoIndex = 'Nebol definovan iadny index!';
$strNoIndexPartsDefined = 'asti indexu neboli definovan!';
$strNoModification = 'iadna zmena';
$strNoOptions = 'Tento formt nem iadne nastavenia';
$strNoPassword = 'iadne heslo';
$strNoPermission = 'Web server nem oprvenia na uloenie do sboru %s.';
$strNoPhp = 'bez PHP kdu';
$strNoPrivileges = 'iadne oprvnenia';
$strNoQuery = 'iadny SQL dotaz!';
$strNoRights = 'Nemte dostaton prva na vykonanie tejto akcie!';
$strNoRowsSelected = 'Nebol vybran iadny riadok';
$strNoSpace = 'Nedostatok miesta pre uloenie sboru %s.';
$strNoTablesFound = 'Neboli njden iadne tabuky v tejto datbaze.';
$strNoUsersFound = 'Nebol njden iadny pouvate.';
$strNoValidateSQL = 'Preskoi potvrdenie platnosti SQL';
$strNone = 'iadny';
$strNotNumber = 'Toto nie je slo!';
$strNotOK = 'chyba';
$strNotSet = 'Tabuka <b>%s</b> nebola njden alebo nie je nastaven v %s';
$strNotValidNumber = ' nie je platn slo riadku!';
$strNull = 'Nulov';
$strNumSearchResultsInTable = '%s vskyt(ov)v tabuke <i>%s</i>';
$strNumSearchResultsTotal = '<b>Celkovo:</b> <i>%s</i> vskyt(ov)';
$strNumTables = 'Tabuky';

$strOK = 'OK';
$strOftenQuotation = 'asto uvodzujce znaky. Volitene znamen, e iba polia typu char a varchar s uzatvoren do "uzatvracch" znakov.';
$strOperations = 'Opercie';
$strOperator = 'Opertor';
$strOptimizeTable = 'Optimalizova tabuku';
$strOptionalControls = 'Voliten. Uruje ako zapisova alebo ta pecilne znaky.';
$strOptionally = 'Volitene';
$strOr = 'alebo';
$strOverhead = 'Naviac';
$strOverwriteExisting = 'Prepsa existujci sbor(y)';

$strPHP40203 = 'Pouvate PHP 4.2.3, ktor ma vnu chybu pri prci s viac bajtovmi znakmi (mbstring). V PHP je tto chyba zdokumentovan pod slom 19404. Nedoporuuje sa pouva tto verziu PHP s phpMyAdminom.';
$strPHPVersion = 'Verzia PHP';
$strPageNumber = 'slo strnky:';
$strPaperSize = 'Vekos strnky';
$strPartialText = 'iaston texty';
$strPassword = 'Heslo';
$strPasswordChanged = 'Heslo pre %s bolo spene zmenen.';
$strPasswordEmpty = 'Heslo je przdne!';
$strPasswordNotSame = 'Hesl sa nezhoduj!';
$strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
$strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
$strPdfNoTables = 'iadne tabuky';
$strPerHour = 'za hodinu';
$strPerMinute = 'za mintu';
$strPerSecond = 'za sekundu';
$strPhoneBook = 'adresr';
$strPhp = 'Vytvori PHP kd';
$strPmaDocumentation = 'phpMyAdmin Dokumentcia';
$strPmaUriError = 'Direktva <tt>$cfg[\'PmaAbsoluteUri\']</tt> v konfiguranom sbore MUS by nastaven!';
$strPolish = 'Potina';
$strPortrait = 'Na vku';
$strPos1 = 'Zaiatok';
$strPrevious = 'Predchdzajci';
$strPrimary = 'Primrny';
$strPrimaryKeyHasBeenDropped = 'Primrny k bol zruen';
$strPrimaryKeyName = 'Nzov primrneho ka mus by... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mus</b> by <b>iba</b> meno primrneho ka!)';
$strPrint = 'Vytlai';
$strPrintView = 'Nhad k tlai';
$strPrintViewFull = 'Nhad tlae (s kompletnmi textami)';
$strPrivDescAllPrivileges = 'Vetky oprvnenia okrem GRANT.';
$strPrivDescAlter = 'Povol meni truktru existujcich tabuliek.';
$strPrivDescCreateDb = 'Povol vytvranie novch databz a tabuliek.';
$strPrivDescCreateTbl = 'Povol vytvranie novch tabuliek.';
$strPrivDescCreateTmpTable = 'Povol vytvranie doasnch tabuliek.';
$strPrivDescDelete = 'Povol mazanie dt.';
$strPrivDescDropDb = 'Povol odstraovanie databz a tabuliek.';
$strPrivDescDropTbl = 'Povol odstraovanie tabuliek.';
$strPrivDescExecute = 'Povol spanie uloench procedr. Nefunguje v tejto verzii MySQL.';
$strPrivDescFile = 'Povol importovanie a exportovanie dt zo/do sborov na serveri.';
$strPrivDescGrant = 'Povol pridvanie uivatelov a prv bez znovunatania tabuliek prv.';
$strPrivDescIndex = 'Povol vytvranie a mazanie indexov.';
$strPrivDescInsert = 'Povol vkladanie a nahradzovanie dt.';
$strPrivDescLockTables = 'Povol zmaknutie tabuliek pre aktulne vlkno.';
$strPrivDescMaxConnections = 'Obmedz poet novch spojen, ktor me pouvate vytvori za hodinu.';
$strPrivDescMaxQuestions = 'Obmedz poet dotazov, ktor me pouvate odosla za hodinu.';
$strPrivDescMaxUpdates = 'Obmedz poet prkazov meniacich tabuku alebo databzu, ktor me pouvate odosla za hodinu.';
$strPrivDescProcess3 = 'Povol zabjanie procesov inm pouvatelom.';
$strPrivDescProcess4 = 'Povol prezeranie kompletnch dotazov v zozname procesov.';
$strPrivDescReferences = 'Nefunguje v tejto verzii MySQL.';
$strPrivDescReload = 'Povol znovunatanie nastaven a vyprzdovanie vyrovnvacch pamt serveru.';
$strPrivDescReplClient = 'Povol pouvateovi zisti kde je hlavn / pomocn server.';
$strPrivDescReplSlave = 'Potrebn pre replikciu pomocnch serverov.';
$strPrivDescSelect = 'Povol tanie dt.';
$strPrivDescShowDb = 'Povol prstup ku kompletnmu zoznamu databz.';
$strPrivDescShutdown = 'Povol vypnutie serveru.';
$strPrivDescSuper = 'Povol spojenie aj v prpade, e bol dosiahnut maximlny poet spojen. Potrebn pre vinu operci pri sprve serveru ako nastavovanie globlny premennch alebo zabjanie procesov inch pouvateov.';
$strPrivDescUpdate = 'Povol menenie dt.';
$strPrivDescUsage = 'iadne prva.';
$strPrivileges = 'Oprvnenia';
$strPrivilegesReloaded = 'Prva boli spene znovunatan.';
$strProcesslist = 'Zoznam procesov';
$strPutColNames = 'Prida nzvy pol na prv riadok';

$strQBE = 'Dotaz poda prkladu';
$strQBEDel = 'Zmaza';
$strQBEIns = 'Vloi';
$strQueryFrame = 'SQL okno';
$strQueryOnDb = ' SQL dotaz v databze <b>%s</b>:';
$strQuerySQLHistory = 'SQL histria';
$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
$strQueryTime = 'Dotaz zabral %01.4f sek.';
$strQueryType = 'Typ dotazu';
$strQueryWindowLock = 'Neprepisova tento dotaz z hlavnho okna';

$strReType = 'Potvrdi';
$strReceived = 'Prijat';
$strRecords = 'Zznamov';
$strReferentialIntegrity = 'Skontrolova referenn integritu:';
$strRefresh = 'Obnovi';
$strRelationNotWorking = 'Prdavn vlastnosti pre prcu s prepojenmi tabukami boli deaktivovan. Ak chcete zisti preo, kliknite %ssem%s.';
$strRelationView = 'Zobrazi spojitosti';
$strRelationalSchema = 'Relan schma';
$strRelations = 'Prepojenia';
$strRelationsForTable = 'VZAHY PRE TABUKU';
$strReloadFailed = 'Znovu-natanie MySQL bolo nespen.';
$strReloadMySQL = 'Znovu-nata MySQL';
$strReloadingThePrivileges = 'Znovunatanie prv';
$strRemoveSelectedUsers = 'Odstrni vybranch pouvateov';
$strRenameDatabaseOK = 'Databza %s bola premenovan na %s';
$strRenameTable = 'Premenova tabuku na';
$strRenameTableOK = 'Tabuka %s bola premenovan na %s';
$strRepairTable = 'Opravi tabuku';
$strReplace = 'Nahradi';
$strReplaceNULLBy = 'Nahradi NULL hodnoty';
$strReplaceTable = 'Nahradi dta v tabuke sborom';
$strReset = 'Pvodn (Reset)';
$strResourceLimits = 'Obmedzenie zdrojov';
$strRevoke = 'Zrui';
$strRevokeAndDelete = 'Odobranie vetkch aktvnych prv pouvateom a ich nsledn odstrnenie.';
$strRevokeAndDeleteDescr = 'Uvatelia bud ma stle prvo USAGE (pouvanie) a do znovunatania prv.';
$strRevokeMessage = 'Boli zruen oprvnenia pre %s';
$strRomanian = 'Rumuntina';
$strRowLength = 'Dka riadku';
$strRowSize = ' Vekos riadku ';
$strRows = 'Riadkov';
$strRowsFrom = 'riadky zanaj od';
$strRowsModeFlippedHorizontal = 'vodorovnom (otoen hlaviky)';
$strRowsModeHorizontal = 'horizontlnom';
$strRowsModeOptions = 'v(o) %s mde a opakova hlaviky po kadch %s bunkch';
$strRowsModeVertical = 'vertiklnom';
$strRowsStatistic = 'tatistika riadku';
$strRunQuery = 'Odoli dotaz';
$strRunSQLQuery = 'Spusti SQL dotaz/dotazy na databzu %s';
$strRunning = 'be na %s';
$strRussian = 'Rutina';

$strSQL = 'SQL';
$strSQLExportType = 'Typ vytvorench dotazov';
$strSQLOptions = 'SQL nastavenia';
$strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dotaz, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dotaze, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dotaz na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
$strSQLParserUserError = 'Vyskytla sa chyba v SQL dotaze. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
$strSQLQuery = 'SQL dotaz';
$strSQLResult = 'vsledok SQL';
$strSQPBugInvalidIdentifer = 'Neplatn identifiktor';
$strSQPBugUnclosedQuote = 'Neuzatvoren vodzovky';
$strSQPBugUnknownPunctuation = 'Neznmy interpunkn reazec';
$strSave = 'Uloi';
$strSaveOnServer = 'Uloi na server do adresra %s';
$strScaleFactorSmall = 'Mierka je prli mala na roztiahnutie schmy na strnku';
$strSearch = 'Hada';
$strSearchFormTitle = 'Hada v databze';
$strSearchInTables = 'V tabuke(ch):';
$strSearchNeedle = 'Slovo() alebo hodnotu(y), ktor chcete vyhada (nahradzujci znak: "%"):';
$strSearchOption1 = 'najmenej jedno zo slov';
$strSearchOption2 = 'vetky slov';
$strSearchOption3 = 'presn vraz';
$strSearchOption4 = 'ako regulrny vraz';
$strSearchResultsFor = 'Prehada vsledky na "<i>%s</i>" %s:';
$strSearchType = 'Njdi:';
$strSecretRequired = 'Nastavte prosm k pre ifrovanie cookies v konfiguranom sbore (blowfish_secret).';
$strSelectADb = 'Prosm vyberte si databzu';
$strSelectAll = 'Oznai vetko';
$strSelectFields = 'Zvoli pole (najmenej jedno):';
$strSelectNumRows = 'v dotaze';
$strSelectTables = 'Vybra Tabuky';
$strSend = 'Poli';
$strSent = 'Odoslan';
$strServer = 'Server';
$strServerChoice = 'Voba serveru';
$strServerNotResponding = 'Server neodpoved';
$strServerStatus = 'Stav serveru';
$strServerStatusUptime = 'Tento server be %s. Bol spusten %s.';
$strServerTabProcesslist = 'Procesy';
$strServerTabVariables = 'Premenn';
$strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
$strServerVars = 'Premenn a nastavenia serveru';
$strServerVersion = 'Verzia serveru';
$strSessionValue = 'Hodnota sedenia';
$strSetEnumVal = 'Ak je pole typu "enum" alebo "set", prosm zadvajte hodnoty v tvare: \'a\',\'b\',\'c\'...<br />Ak dokonca potrebujete zada sptn lomtko ("\") alebo apostrof ("\'") pri tchto hodnotch, zadajte ich naprklad takto \'\\\\xyz\' alebo \'a\\\'b\'.';
$strShow = 'Ukza';
$strShowAll = 'Zobrazi vetko';
$strShowColor = 'Zobrazi farbu';
$strShowDatadictAs = 'Formt dtovho slovnka';
$strShowFullQueries = 'Zobrazi kompletn dotazy';
$strShowGrid = 'Zobrazi mrieku';
$strShowPHPInfo = 'Zobrazi informcie o PHP';
$strShowTableDimension = 'Zobrazi rozmery tabuliek';
$strShowTables = 'Zobrazi tabuky';
$strShowThisQuery = ' Zobrazi tento dotaz znovu ';
$strShowingRecords = 'Ukza zznamy ';
$strSimplifiedChinese = 'Zjednoduen ntina';
$strSingly = '(po jednom)';
$strSize = 'Vekos';
$strSlovak = 'Slovenina';
$strSlovenian = 'Slovinina';
$strSort = 'Triedi';
$strSortByKey = 'Zoradi poda ka';
$strSpaceUsage = 'Zabran miesto';
$strSpanish = 'panielsky';
$strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
$strStatCheckTime = 'Posledn kontrola';
$strStatCreateTime = 'Vytvorenie';
$strStatUpdateTime = 'Posledn zmena';
$strStatement = 'daj';
$strStatus = 'Stav';
$strStrucCSV = 'CSV dta';
$strStrucData = 'truktru a dta';
$strStrucDrop = 'Pridaj \'vyma tabuku\'';
$strStrucExcelCSV = 'CSV pre MS Excel dta';
$strStrucNativeExcel = 'Natvne dta MS Excel';
$strStrucOnly = 'Iba truktru';
$strStructPropose = 'Navrhn truktru tabuky';
$strStructure = 'truktra';
$strSubmit = 'Odoli';
$strSuccess = 'SQL dotaz bol spene vykonan';
$strSum = 'Celkom';
$strSwedish = 'vdsky';
$strSwitchToTable = 'Prepn na skoprovan tabuku';

$strTable = 'Tabuka';
$strTableComments = 'Komentr k tabuke';
$strTableEmpty = 'Tabuka je przdna!';
$strTableHasBeenDropped = 'Tabuka %s bola odstrnen';
$strTableHasBeenEmptied = 'Tabuka %s bola vyprzden';
$strTableHasBeenFlushed = 'Tabuka %s bola vyprzdnen';
$strTableMaintenance = 'drba tabuky';
$strTableOfContents = 'Obsah';
$strTableOptions = 'Parametre tabuky';
$strTableStructure = 'truktra tabuky pre tabuku';
$strTableType = 'Typ tabuky';
$strTables = '%s tabuka(y)';
$strTakeIt = 'zvoli';
$strTblPrivileges = 'Oprvnenia pre jednotliv tabuky';
$strTextAreaLength = ' Toto mono nepjde upravi,<br /> kvli svojej dke ';
$strThai = 'Thajina';
$strTheContent = 'Obsah Vho sboru bol vloen.';
$strTheContents = 'Obsah sboru prepe obsah vybranej tabuky v riadkoch s identickm primrnym alebo uniktnym kom.';
$strTheTerminator = 'Ukonenie pol.';
$strTheme = 'Vzhad';
$strThisHost = 'Tento pota';
$strThisNotDirectory = 'Nebol zadan adresr';
$strThreadSuccessfullyKilled = 'Vlkno %s bol spene zabit.';
$strTime = 'as';
$strToggleScratchboard = 'zobrazi grafick nvrh';
$strTotal = 'celkovo';
$strTotalUC = 'Celkom';
$strTraditionalChinese = 'Tradin ntina';
$strTraditionalSpanish = 'Tradin panielina';
$strTraffic = 'Prevdzka';
$strTransformation_application_octetstream__download = 'Zobraz odkaz na stiahnutie dt. Prv parameter je meno sboru, druh je meno stpca v tabuke obsahujci meno sboru. Ak zadte druh parameter, prv mus by przdny.';
$strTransformation_image_jpeg__inline = 'Zobraz nhad obrzku s odkazom na obrzok; parametre rka a vka v bodoch (pomer strn obrzku zostane zachovan)';
$strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzok (napr. stiahnutie poa blob).';
$strTransformation_image_png__inline = 'Zobraz image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Zobraz dtum alebo as (TIME, TIMESTAMP alebo DATETIME) poda miestneho nastavenia. Prv parameter je posun (v hodinch), ktor bude pridan k zadanmu asu (predvolen je 0). Druh parameter je formtovac reazec pre php funkciu strftime().';
$strTransformation_text_plain__external = 'PLAT IBA PRE LINUX: Spust extern aplikciu, na jej tandardn vstup pole pole a zobraz vstup programu. Predvolen program je Tidy, ktor pekne sformtuje HTML. Z bezpenostnch dvodov muste rune upravi obsah sboru libraries/transformations/text_plain__external.inc.php a prida do neho povolen aplikcie. Prv parameter je slo aplikcie, ktor chcete poui a druh parametre s parametre tejto aplikcie. Ak je tret parameter nastaven na 1, vstup bude skonvertovan funkciou htmlspecialchars() (predvolen je 1). tvrt parameter v prpade, e je nastaven na 1 prid k vstupnmu textu parameter NOWRAP, m zabezpe zachovanie formtovania (predvolen je 1)';
$strTransformation_text_plain__formatted = 'Zachov pvodn formtovanie poa tak ako je uloen v databze.';
$strTransformation_text_plain__imagelink = 'Zobraz obrzok a odkaz z poa obsahujceho odkaz na obrzok. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh a tret parameter uruj rku a vku obrzku.';
$strTransformation_text_plain__link = 'Zobraz odkaz z poa obsahujceho odkaz. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh parameter je text odkazu.';
$strTransformation_text_plain__substr = 'Zobraz iba as reazca. Prv parameter je posun od zaiatku (predvolen je 0) a druh uruje dku textu, ktor sa ma zobrazi, ak nie je zadan bude zobrazen zvyok textu. Tret parameter uruje znaky, ktor bud pridan na koniec skrtenho textu (predvolen je ...).';
$strTruncateQueries = 'Zobrazi skrtene dotazy';
$strTurkish = 'Turecky';
$strType = 'Typ';

$strUkrainian = 'Ukrajinsky';
$strUncheckAll = 'Odznai vetko';
$strUnicode = 'Unicode';
$strUnique = 'Uniktny';
$strUnknown = 'neznmy';
$strUnselectAll = 'Odznai vetko';
$strUpdComTab = 'Prosm pretajte si dokumentciu ako aktualizova tabuku s informciami o stpcoch (Column_comments Table)';
$strUpdatePrivMessage = 'Boli aktualizovan oprvnenia pre %s.';
$strUpdateProfileMessage = 'Profil bol aktualizovan.';
$strUpdateQuery = 'Aktualizova dotaz';
$strUpgrade = 'Mali by ste aktualizova %s na verziu %s alebo vyiu.';
$strUsage = 'Vyuitie';
$strUseBackquotes = ' Poui opan apostrof pri nzvoch tabuliek a pol ';
$strUseHostTable = 'Poui tabuku s hostitemi';
$strUseTables = 'Poui tabuky';
$strUseTextField = 'Poi textov pole';
$strUseThisValue = 'Poui tto hodnotu';
$strUser = 'Pouvate';
$strUserAlreadyExists = 'Pouvate %s u existuje!';
$strUserEmpty = 'Meno pouvatea je przdne!';
$strUserName = 'Meno pouvatea';
$strUserNotFound = 'Zvolen pouvate nebol njden v tabuke prv.';
$strUserOverview = 'Prehad uvatelov';
$strUsersDeleted = 'Vybran uvatelia bol spene odstrnen.';
$strUsersHavingAccessToDb = 'Pouvatelia majci prstup k &quot;%s&quot;';

$strValidateSQL = 'Potvrdi platnos SQL';
$strValidatorError = 'SQL validator nemohol by inicializovan. Prosm skontrolujte, i s naintalovan vetky potrebn rozrenia php, tak ako s popsan v %sdocumentation%s.';
$strValue = 'Hodnota';
$strVar = 'Premenn';
$strViewDump = 'Zobrazi dump (schmu) tabuky';
$strViewDumpDB = 'Zobrazi dump (schmu) databzy';
$strViewDumpDatabases = 'Export databz';

$strWebServerUploadDirectory = 'upload adresr web serveru';
$strWebServerUploadDirectoryError = 'Adresr uren pre upload sborov sa ned otvori';
$strWelcome = 'Vitajte v %s';
$strWestEuropean = 'Zpadn Eurpa';
$strWildcard = 'nahradzujci znak';
$strWindowNotFound = 'Cieov okno prehliadaa nemohlo by aktualizovan. Mono ste zatvorili rodiovsk okno, alebo prehliada blokuje opercie medzi oknami z dvodu bezpenostnch nastaven';
$strWithChecked = 'Vber:';
$strWritingCommentNotPossible = 'Komentr sa ned zapsa';
$strWritingRelationNotPossible = 'Vzah sa ned zapsa';
$strWrongUser = 'Zl pouvatesk meno alebo heslo. Prstup zamietnut.';

$strXML = 'XML';

$strYes = 'no';

$strZeroRemovesTheLimit = 'Poznmka: Nastavenie tchto parametrov na 0 (nulu) odstrni obmedzenia.';
$strZip = '"zo zipovan"';

$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
?>
